@@ -54,14 +54,26 @@ pub mod experiment_device_config;
 pub use self::experiment_device_config::ExperimentDeviceConfig;
 pub mod gcode_file;
 pub use self::gcode_file::GcodeFile;
-pub mod janus_auth;
-pub use self::janus_auth::JanusAuth;
-pub mod janus_auth_request;
-pub use self::janus_auth_request::JanusAuthRequest;
+pub mod janus_cloud_auth;
+pub use self::janus_cloud_auth::JanusCloudAuth;
+pub mod janus_cloud_auth_request;
+pub use self::janus_cloud_auth_request::JanusCloudAuthRequest;
+pub mod janus_edge_auth;
+pub use self::janus_edge_auth::JanusEdgeAuth;
+pub mod janus_edge_auth_request;
+pub use self::janus_edge_auth_request::JanusEdgeAuthRequest;
 pub mod mobile_auth_request;
 pub use self::mobile_auth_request::MobileAuthRequest;
 pub mod model_artifact;
 pub use self::model_artifact::ModelArtifact;
+pub mod monitor_start_task;
+pub use self::monitor_start_task::MonitorStartTask;
+pub mod monitor_start_task_request;
+pub use self::monitor_start_task_request::MonitorStartTaskRequest;
+pub mod monitor_stop_task;
+pub use self::monitor_stop_task::MonitorStopTask;
+pub mod monitor_stop_task_request;
+pub use self::monitor_stop_task_request::MonitorStopTaskRequest;
 pub mod octo_generic_event;
 pub use self::octo_generic_event::OctoGenericEvent;
 pub mod octo_job_event;
@@ -128,10 +140,6 @@ pub mod octoprint_python;
 pub use self::octoprint_python::OctoprintPython;
 pub mod octoprint_python_request;
 pub use self::octoprint_python_request::OctoprintPythonRequest;
-pub mod onboarding_task;
-pub use self::onboarding_task::OnboardingTask;
-pub mod onboarding_task_request;
-pub use self::onboarding_task_request::OnboardingTaskRequest;
 pub mod paginated_alert_list;
 pub use self::paginated_alert_list::PaginatedAlertList;
 pub mod paginated_camera_list;
@@ -148,8 +156,10 @@ pub mod paginated_experiment_list;
 pub use self::paginated_experiment_list::PaginatedExperimentList;
 pub mod paginated_gcode_file_list;
 pub use self::paginated_gcode_file_list::PaginatedGcodeFileList;
-pub mod paginated_janus_auth_list;
-pub use self::paginated_janus_auth_list::PaginatedJanusAuthList;
+pub mod paginated_janus_cloud_auth_list;
+pub use self::paginated_janus_cloud_auth_list::PaginatedJanusCloudAuthList;
+pub mod paginated_janus_edge_auth_list;
+pub use self::paginated_janus_edge_auth_list::PaginatedJanusEdgeAuthList;
 pub mod paginated_model_artifact_list;
 pub use self::paginated_model_artifact_list::PaginatedModelArtifactList;
 pub mod paginated_octo_print_backup_list;
@@ -158,10 +168,10 @@ pub mod paginated_octo_print_device_list;
 pub use self::paginated_octo_print_device_list::PaginatedOctoPrintDeviceList;
 pub mod paginated_octo_print_event_list;
 pub use self::paginated_octo_print_event_list::PaginatedOctoPrintEventList;
-pub mod paginated_onboarding_task_list;
-pub use self::paginated_onboarding_task_list::PaginatedOnboardingTaskList;
 pub mod paginated_polymorphic_event_list;
 pub use self::paginated_polymorphic_event_list::PaginatedPolymorphicEventList;
+pub mod paginated_polymorphic_task_list;
+pub use self::paginated_polymorphic_task_list::PaginatedPolymorphicTaskList;
 pub mod paginated_print_job_event_list;
 pub use self::paginated_print_job_event_list::PaginatedPrintJobEventList;
 pub mod paginated_print_nanny_plugin_event_list;
@@ -180,8 +190,6 @@ pub mod paginated_remote_control_command_list;
 pub use self::paginated_remote_control_command_list::PaginatedRemoteControlCommandList;
 pub mod paginated_system_info_list;
 pub use self::paginated_system_info_list::PaginatedSystemInfoList;
-pub mod paginated_task_list;
-pub use self::paginated_task_list::PaginatedTaskList;
 pub mod paginated_task_status_list;
 pub use self::paginated_task_status_list::PaginatedTaskStatusList;
 pub mod paginated_telemetry_event_polymorphic_list;
@@ -202,8 +210,8 @@ pub mod patched_device_calibration_request;
 pub use self::patched_device_calibration_request::PatchedDeviceCalibrationRequest;
 pub mod patched_device_request;
 pub use self::patched_device_request::PatchedDeviceRequest;
-pub mod patched_janus_auth_request;
-pub use self::patched_janus_auth_request::PatchedJanusAuthRequest;
+pub mod patched_janus_edge_auth_request;
+pub use self::patched_janus_edge_auth_request::PatchedJanusEdgeAuthRequest;
 pub mod patched_octo_print_device_request;
 pub use self::patched_octo_print_device_request::PatchedOctoPrintDeviceRequest;
 pub mod patched_polymorphic_event_request;
@@ -228,6 +236,10 @@ pub mod polymorphic_event;
 pub use self::polymorphic_event::PolymorphicEvent;
 pub mod polymorphic_event_request;
 pub use self::polymorphic_event_request::PolymorphicEventRequest;
+pub mod polymorphic_task;
+pub use self::polymorphic_task::PolymorphicTask;
+pub mod polymorphic_task_request;
+pub use self::polymorphic_task_request::PolymorphicTaskRequest;
 pub mod print_job_event;
 pub use self::print_job_event::PrintJobEvent;
 pub mod print_job_event_request;
@@ -278,18 +290,16 @@ pub mod system_info_request;
 pub use self::system_info_request::SystemInfoRequest;
 pub mod task;
 pub use self::task::Task;
-pub mod task_enum;
-pub use self::task_enum::TaskEnum;
 pub mod task_request;
 pub use self::task_request::TaskRequest;
 pub mod task_status;
 pub use self::task_status::TaskStatus;
 pub mod task_status_request;
 pub use self::task_status_request::TaskStatusRequest;
-pub mod task_status_type;
-pub use self::task_status_type::TaskStatusType;
-pub mod task_type;
-pub use self::task_type::TaskType;
+pub mod task_status_status_enum;
+pub use self::task_status_status_enum::TaskStatusStatusEnum;
+pub mod tasktype_enum;
+pub use self::tasktype_enum::TasktypeEnum;
 pub mod telemetry_event;
 pub use self::telemetry_event::TelemetryEvent;
 pub mod telemetry_event_polymorphic;
